@@ -312,6 +312,14 @@ test_that("describe_ipam_byoasn", {
   expect_error(svc$describe_ipam_byoasn(MaxResults = 20), NA)
 })
 
+test_that("describe_ipam_external_resource_verification_tokens", {
+  expect_error(svc$describe_ipam_external_resource_verification_tokens(), NA)
+})
+
+test_that("describe_ipam_external_resource_verification_tokens", {
+  expect_error(svc$describe_ipam_external_resource_verification_tokens(MaxResults = 20), NA)
+})
+
 test_that("describe_ipam_pools", {
   expect_error(svc$describe_ipam_pools(), NA)
 })
@@ -660,6 +668,14 @@ test_that("describe_tags", {
   expect_error(svc$describe_tags(MaxResults = 20), NA)
 })
 
+test_that("describe_traffic_mirror_filter_rules", {
+  expect_error(svc$describe_traffic_mirror_filter_rules(), NA)
+})
+
+test_that("describe_traffic_mirror_filter_rules", {
+  expect_error(svc$describe_traffic_mirror_filter_rules(MaxResults = 20), NA)
+})
+
 test_that("describe_traffic_mirror_filters", {
   expect_error(svc$describe_traffic_mirror_filters(), NA)
 })
